package gui.resource;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.util.HashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;

import javax.swing.Icon;
import javax.swing.ImageIcon;

import core.io.Application;

public class ResourceManager2 extends ResourceManager {

	private Map<String, String> localizedStrings;
	private Application app;
	
	public ResourceManager2(Application app, Locale locale) {
		localizedStrings=new HashMap<>();
		this.app=app;
		System.out.println(app.getExecPath());
		setLocale(locale); 
	}
	
	@Override
	public String getLocalizedString(String key) {
		if (!localizedStrings.containsKey(key)){
			System.out.println(key);
			throw new RuntimeException();
		}
		return localizedStrings.get(key);
	}

	@Override
	public void setLocale(Locale l) {
		localizedStrings.clear();
		Path p=app.getExecPath().resolve("locale").resolve(".properties");
		
		try {
			if (Files.exists(p)) 
				loadList(p);
			
			loadList(app.getExecPath().resolve("locale").resolve("_"+l.getLanguage()+".properties"));
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		
	}

	private void loadList(Path path) throws IOException {
		List<String> list=Files.readAllLines(path,Application.UTF8);
		for (String line:list) {
			line=line.trim();
			if (line.length()>0&& line.charAt(0)!='#') {
				int k=line.indexOf('=');
				if (k>-1) {
					String key=line.substring(0, k);
					String value=line.substring(k+1);
				//	System.out.println("put "+key +" "+value);
					localizedStrings.put(key, value);
				}
			}
		}
	}
	
	@Override
	public Icon getIcon(String string) {
		return new ImageIcon(app.getExecPath().resolve("icons").resolve(getLocalizedString(string)).toString());
	}
	
}
